@@ -36,7 +36,7 @@ class AlgorithmDaemon:
         # pylint: disable=maybe-no-member
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
-            status=ReportStatusRequest.Pending))
+            status=ReportStatusRequest.Pending), timeout=3)
         self.__establist_connect()
 
     def shutdown(self):
@@ -44,14 +44,14 @@ class AlgorithmDaemon:
         # pylint: disable=maybe-no-member
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
-            status=ReportStatusRequest.Completed))
+            status=ReportStatusRequest.Completed), timeout=3)
 
     def __establist_connect(self):
         logger.info("Established connection to agent service.")
         # pylint: disable=maybe-no-member
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
-            status=ReportStatusRequest.Running))
+            status=ReportStatusRequest.Running), timeout=3)
 
     def report_progress(self, progress):
         if progress < 0 or progress > 1:
@@ -59,7 +59,7 @@ class AlgorithmDaemon:
          # pylint: disable=maybe-no-member
         self.__worker_stub.ReportProgress(ReportProgressRequest(
             clientAddress=WorkerIdentity,
-            progress=progress))
+            progress=progress), timeout=3)
 
     def on_failed(self, exception):
         logger.error(exception)
@@ -67,4 +67,4 @@ class AlgorithmDaemon:
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
             status=ReportStatusRequest.Faulted,
-            message=str(exception)))
+            message=str(exception), timeout=3))
